@@ -24,7 +24,7 @@ class PACBatchProbabilisticTeacher(PACProbabilisticTeacher):
         suffixes = [self.terminal_symbol]
 
         for symbol in self.alphabet.symbols:
-            suffixes.append(Sequence(symbol))
+            suffixes.append(Sequence((symbol,)))
 
         rand_words = self._sequence_generator.generate_words(sample_size)
         np.sort(rand_words)
