@@ -20,10 +20,11 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         teacher1 = PDFATeacher(model, WFAToleranceComparator())
         teacher2 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(), sample_size=500, 
                                               max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator=WFAToleranceComparator(), max_seq_length=20)
-        result1 = self.learner.learn(teacher1, tolerance=0, verbose=True)
-        result2 = self.learner.learn(teacher2, tolerance=0, verbose=True)
-        result3 = self.learner.learn(teacher3, tolerance=0, verbose=True)
+        teacher3 = PACProbabilisticTeacher(model, comparator=WFAToleranceComparator(), epsilon=0.05, delta=0.01,
+                                           max_seq_length=20)
+        result1 = self.learner.learn(teacher1, verbose=True)
+        result2 = self.learner.learn(teacher2, verbose=True)
+        result3 = self.learner.learn(teacher3, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -37,10 +38,11 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         teacher1 = PDFATeacher(model, WFAToleranceComparator())
         teacher2 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(), sample_size=500, 
                                               max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator=WFAToleranceComparator(), max_seq_length=20)
-        result1 = self.learner.learn(teacher1, tolerance=0, verbose=True)
-        result2 = self.learner.learn(teacher2, tolerance=0, verbose=True)
-        result3 = self.learner.learn(teacher3, tolerance=0, verbose=True)
+        teacher3 = PACProbabilisticTeacher(model, comparator=WFAToleranceComparator(), epsilon=0.05, delta=0.01,
+                                           max_seq_length=20)
+        result1 = self.learner.learn(teacher1, verbose=True)
+        result2 = self.learner.learn(teacher2, verbose=True)
+        result3 = self.learner.learn(teacher3, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -55,11 +57,11 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))
         teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, 
                                               max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance),
-                                           max_seq_length=20)
-        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
-        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
-        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
+        teacher3 = PACProbabilisticTeacher(model, comparator=WFAToleranceComparator(tolerance), epsilon=0.05,
+                                           delta=0.01, max_seq_length=20)
+        result1 = self.learner.learn(teacher1, verbose=True)
+        result2 = self.learner.learn(teacher2, verbose=True)
+        result3 = self.learner.learn(teacher3, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -73,11 +75,11 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))        
         teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, 
                                               max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance), 
-                                           max_seq_length=20)
-        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
-        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
-        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
+        teacher3 = PACProbabilisticTeacher(model, comparator=WFAToleranceComparator(tolerance), epsilon=0.05,
+                                           delta=0.01, max_seq_length=20)
+        result1 = self.learner.learn(teacher1, verbose=True)
+        result2 = self.learner.learn(teacher2, verbose=True)
+        result3 = self.learner.learn(teacher3, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -92,11 +94,11 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))        
         teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, 
                                               max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance), 
-                                           max_seq_length=20)
-        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
-        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
-        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
+        teacher3 = PACProbabilisticTeacher(model, comparator=WFAToleranceComparator(tolerance), epsilon=0.05,
+                                           delta=0.01, max_seq_length=20)
+        result1 = self.learner.learn(teacher1, verbose=True)
+        result2 = self.learner.learn(teacher2, verbose=True)
+        result3 = self.learner.learn(teacher3, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -110,11 +112,11 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))        
         teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, 
                                               max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance), 
-                                           max_seq_length=20)
-        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
-        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
-        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
+        teacher3 = PACProbabilisticTeacher(model, comparator=WFAToleranceComparator(tolerance), epsilon=0.05,
+                                           delta=0.01, max_seq_length=20)
+        result1 = self.learner.learn(teacher1, verbose=True)
+        result2 = self.learner.learn(teacher2, verbose=True)
+        result3 = self.learner.learn(teacher3, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -128,11 +130,11 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))        
         teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, 
                                               max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance), 
-                                           max_seq_length=20)
-        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
-        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
-        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
+        teacher3 = PACProbabilisticTeacher(model, comparator=WFAToleranceComparator(tolerance), epsilon=0.05,
+                                           delta=0.01, max_seq_length=20)
+        result1 = self.learner.learn(teacher1, verbose=True)
+        result2 = self.learner.learn(teacher2, verbose=True)
+        result3 = self.learner.learn(teacher3, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
